@@ -23,7 +23,7 @@ from typing import (
 
 import pipx.constants
 from pipx.animate import show_cursor
-from pipx.constants import PIPX_TRASH_DIR, WINDOWS
+from pipx.constants import MINGW, PIPX_TRASH_DIR, WINDOWS
 
 logger = logging.getLogger(__name__)
 
@@ -54,25 +54,18 @@ def rmdir(path: Path, safe_rm: bool = True) -> None:
 
     logger.info(f"removing directory {path}")
     try:
-        if WINDOWS:
-            os.system(f'rmdir /S /Q "{str(path)}"')
-        else:
-            shutil.rmtree(path)
+        shutil.rmtree(path)
     except FileNotFoundError:
         pass
 
     # move it to be deleted later if it still exists
     if path.is_dir():
         if safe_rm:
-            logger.warning(
-                f"Failed to delete {path}. Will move it to a temp folder to delete later."
-            )
+            logger.warning(f"Failed to delete {path}. Will move it to a temp folder to delete later.")
 
             path.rename(_get_trash_file(path))
         else:
-            logger.warning(
-                f"Failed to delete {path}. You may need to delete it manually."
-            )
+            logger.warning(f"Failed to delete {path}. You may need to delete it manually.")
 
 
 def mkdir(path: Path) -> None:
@@ -114,17 +107,19 @@ def run_pypackage_bin(bin_path: Path, args: List[str]) -> NoReturn:
 
 if WINDOWS:
 
-    def get_venv_paths(root: Path) -> Tuple[Path, Path]:
-        bin_path = root / "Scripts"
+    def get_venv_paths(root: Path) -> Tuple[Path, Path, Path]:
+        bin_path = root / "Scripts" if not MINGW else root / "bin"
         python_path = bin_path / "python.exe"
-        return bin_path, python_path
+        man_path = root / "share" / "man"
+        return bin_path, python_path, man_path
 
 else:
 
-    def get_venv_paths(root: Path) -> Tuple[Path, Path]:
+    def get_venv_paths(root: Path) -> Tuple[Path, Path, Path]:
         bin_path = root / "bin"
         python_path = bin_path / "python"
-        return bin_path, python_path
+        man_path = root / "share" / "man"
+        return bin_path, python_path, man_path
 
 
 def get_site_packages(python: Path) -> Path:
@@ -150,6 +145,7 @@ def _fix_subprocess_env(env: Dict[str, str]) -> Dict[str, str]:
     env["PIP_DISABLE_PIP_VERSION_CHECK"] = "1"
     # Make sure that Python writes output in UTF-8
     env["PYTHONIOENCODING"] = "utf-8"
+    env["PYTHONLEGACYWINDOWSSTDIO"] = "utf-8"
     # Make sure we install package to venv, not userbase dir
     env["PIP_USER"] = "0"
     return env
@@ -172,6 +168,14 @@ def run_subprocess(
     logger.info(f"running {log_cmd_str}")
     # windows cannot take Path objects, only strings
     cmd_str_list = [str(c) for c in cmd]
+    # Make sure to call the binary using its real path. This matters especially on Windows when using the packaged app
+    # (Microsoft Store) version of Python, which uses path redirection for sandboxing. If the path to the executable is
+    # redirected, the executable can get confused as to which directory it's being run from, leading to problems.
+    # See https://github.com/pypa/pipx/issues/1164
+    # Conversely, if the binary is a symlink, then we should NOT use the real path, as Python expects to receive the
+    # symlink in argv[0] so that it can locate the venv.
+    if not os.path.islink(cmd_str_list[0]) and WINDOWS:
+        cmd_str_list[0] = os.path.realpath(cmd_str_list[0])
     completed_process = subprocess.run(
         cmd_str_list,
         env=env,
@@ -179,6 +183,7 @@ def run_subprocess(
         stderr=subprocess.PIPE if capture_stderr else None,
         encoding="utf-8",
         universal_newlines=True,
+        check=False,
     )
 
     if capture_stdout and log_stdout:
@@ -190,18 +195,14 @@ def run_subprocess(
     return completed_process
 
 
-def subprocess_post_check(
-    completed_process: "subprocess.CompletedProcess[str]", raise_error: bool = True
-) -> None:
+def subprocess_post_check(completed_process: "subprocess.CompletedProcess[str]", raise_error: bool = True) -> None:
     if completed_process.returncode:
         if completed_process.stdout is not None:
             print(completed_process.stdout, file=sys.stdout, end="")
         if completed_process.stderr is not None:
             print(completed_process.stderr, file=sys.stderr, end="")
         if raise_error:
-            raise PipxError(
-                f"{' '.join([str(x) for x in completed_process.args])!r} failed"
-            )
+            raise PipxError(f"{' '.join([str(x) for x in completed_process.args])!r} failed")
         else:
             logger.info(f"{' '.join(completed_process.args)!r} failed")
 
@@ -294,16 +295,12 @@ def analyze_pip_output(pip_stdout: str, pip_stderr: str) -> None:
         failed_to_build_str = "\n    ".join(failed_build_stdout)
         plural_str = "s" if len(failed_build_stdout) > 1 else ""
         print("", file=sys.stderr)
-        logger.error(
-            f"pip failed to build package{plural_str}:\n    {failed_to_build_str}"
-        )
+        logger.error(f"pip failed to build package{plural_str}:\n    {failed_to_build_str}")
     elif failed_build_stderr:
         failed_to_build_str = "\n    ".join(failed_build_stderr)
         plural_str = "s" if len(failed_build_stderr) > 1 else ""
         print("", file=sys.stderr)
-        logger.error(
-            f"pip seemed to fail to build package{plural_str}:\n    {failed_to_build_str}"
-        )
+        logger.error(f"pip seemed to fail to build package{plural_str}:\n    {failed_to_build_str}")
     elif last_collecting_dep is not None:
         print("", file=sys.stderr)
         logger.error(f"pip seemed to fail to build package:\n    {last_collecting_dep}")
@@ -315,13 +312,9 @@ def analyze_pip_output(pip_stdout: str, pip_stderr: str) -> None:
 
         print_categories = [x.category for x in relevant_searches]
         relevants_saved_filtered = relevants_saved.copy()
-        while (len(print_categories) > 1) and (
-            len(relevants_saved_filtered) > max_relevant_errors
-        ):
+        while (len(print_categories) > 1) and (len(relevants_saved_filtered) > max_relevant_errors):
             print_categories.pop(-1)
-            relevants_saved_filtered = [
-                x for x in relevants_saved if x[1] in print_categories
-            ]
+            relevants_saved_filtered = [x for x in relevants_saved if x[1] in print_categories]
 
         for relevant_saved in relevants_saved_filtered:
             print(f"    {relevant_saved[0]}", file=sys.stderr)
@@ -335,10 +328,8 @@ def subprocess_post_check_handle_pip_error(
         # Save STDOUT and STDERR to file in pipx/logs/
         if pipx.constants.pipx_log_file is None:
             raise PipxError("Pipx internal error: No log_file present.")
-        pip_error_file = pipx.constants.pipx_log_file.parent / (
-            pipx.constants.pipx_log_file.stem + "_pip_errors.log"
-        )
-        with pip_error_file.open("w") as pip_error_fh:
+        pip_error_file = pipx.constants.pipx_log_file.parent / (pipx.constants.pipx_log_file.stem + "_pip_errors.log")
+        with pip_error_file.open("w", encoding="utf-8") as pip_error_fh:
             print("PIP STDOUT", file=pip_error_fh)
             print("----------", file=pip_error_fh)
             if completed_process.stdout is not None:
@@ -348,10 +339,7 @@ def subprocess_post_check_handle_pip_error(
             if completed_process.stderr is not None:
                 print(completed_process.stderr, file=pip_error_fh, end="")
 
-        logger.error(
-            "Fatal error from pip prevented installation. Full pip output in file:\n"
-            f"    {pip_error_file}"
-        )
+        logger.error("Fatal error from pip prevented installation. Full pip output in file:\n" f"    {pip_error_file}")
 
         analyze_pip_output(completed_process.stdout, completed_process.stderr)
 
@@ -363,7 +351,7 @@ def exec_app(
 ) -> NoReturn:
     """Run command, do not return
 
-    POSIX: replace current processs with command using os.exec*()
+    POSIX: replace current process with command using os.exec*()
     Windows: Use subprocess and sys.exit() to run command
     """
 
@@ -373,12 +361,7 @@ def exec_app(
 
     if extra_python_paths is not None:
         env["PYTHONPATH"] = os.path.pathsep.join(
-            extra_python_paths
-            + (
-                os.getenv("PYTHONPATH", "").split(os.path.pathsep)
-                if os.getenv("PYTHONPATH")
-                else []
-            )
+            extra_python_paths + (os.getenv("PYTHONPATH", "").split(os.path.pathsep) if os.getenv("PYTHONPATH") else [])
         )
 
     # make sure we show cursor again before handing over control
@@ -395,6 +378,7 @@ def exec_app(
                 stderr=None,
                 encoding="utf-8",
                 universal_newlines=True,
+                check=False,
             ).returncode
         )
     else:
@@ -408,9 +392,7 @@ def full_package_description(package_name: str, package_spec: str) -> str:
         return f"{package_name} from spec {package_spec!r}"
 
 
-def pipx_wrap(
-    text: str, subsequent_indent: str = "", keep_newlines: bool = False
-) -> str:
+def pipx_wrap(text: str, subsequent_indent: str = "", keep_newlines: bool = False) -> str:
     """Dedent, strip, wrap to shell width. Don't break on hyphens, only spaces"""
     minimum_width = 40
     width = max(shutil.get_terminal_size((80, 40)).columns, minimum_width) - 2
