@@ -13,9 +13,7 @@ from pipx import shared_libs
         (-shared_libs.SHARED_LIBS_MAX_AGE_SEC + 5 * 60, False),
     ],
 )
-def test_auto_update_shared_libs(
-    capsys, pipx_ultra_temp_env, mtime_minus_now, needs_upgrade
-):
+def test_auto_update_shared_libs(capsys, pipx_ultra_temp_env, mtime_minus_now, needs_upgrade):
     now = time.time()
     shared_libs.shared_libs.create(verbose=True)
     shared_libs.shared_libs.has_been_updated_this_run = False
